From: Roman Kisel <romank@linux.microsoft.com>
To: arnd@arndb.de, bp@alien8.de, corbet@lwn.net,
dave.hansen@linux.intel.com, decui@microsoft.com,
haiyangz@microsoft.com, hpa@zytor.com, kys@microsoft.com,
mikelley@microsoft.com, mingo@redhat.com, tglx@linutronix.de,
Tianyu.Lan@microsoft.com, wei.liu@kernel.org, x86@kernel.org,
linux-hyperv@vger.kernel.org, linux-doc@vger.kernel.org,
linux-kernel@vger.kernel.org, linux-arch@vger.kernel.org
Cc: benhill@microsoft.com, bperkins@microsoft.com,
sunilmut@microsoft.com, romank@linux.microsoft.com
Subject: [PATCH hyperv-next v5 10/16] Drivers: hv: Rename the SynIC enable and disable routines
Date: Wed, 27 Aug 2025 18:05:51 -0700 [thread overview]
Message-ID: <20250828010557.123869-11-romank@linux.microsoft.com> (raw)
In-Reply-To: <20250828010557.123869-1-romank@linux.microsoft.com>
The confidential VMBus requires support for the both hypervisor
facing SynIC and the paravisor one.
Rename the functions that enable and disable SynIC with the
hypervisor. No functional changes.
Signed-off-by: Roman Kisel <romank@linux.microsoft.com>
Reviewed-by: Tianyu Lan <tiala@microsoft.com>
Reviewed-by: Michael Kelley <mhklinux@outlook.com>
---
drivers/hv/channel_mgmt.c | 2 +-
drivers/hv/hv.c | 11 ++++++-----
drivers/hv/hyperv_vmbus.h | 4 ++--
drivers/hv/vmbus_drv.c | 6 +++---
4 files changed, 12 insertions(+), 11 deletions(-)
diff --git a/drivers/hv/channel_mgmt.c b/drivers/hv/channel_mgmt.c
index 1a33c6944b3c..6d66cbc9030b 100644
--- a/drivers/hv/channel_mgmt.c
+++ b/drivers/hv/channel_mgmt.c
@@ -846,7 +846,7 @@ static void vmbus_wait_for_unload(void)
/*
* In a CoCo VM the hyp_synic_message_page is not allocated
* in hv_synic_alloc(). Instead it is set/cleared in
- * hv_synic_enable_regs() and hv_synic_disable_regs()
+ * hv_hyp_synic_enable_regs() and hv_hyp_synic_disable_regs()
* such that it is set only when the CPU is online. If
* not all present CPUs are online, the message page
* might be NULL, so skip such CPUs.
diff --git a/drivers/hv/hyperv_vmbus.h b/drivers/hv/hyperv_vmbus.h
index 095a5c758e93..545aedf2d03c 100644
--- a/drivers/hv/hyperv_vmbus.h
+++ b/drivers/hv/hyperv_vmbus.h
@@ -191,10 +191,10 @@ extern int hv_synic_alloc(void);
extern void hv_synic_free(void);
-extern void hv_synic_enable_regs(unsigned int cpu);
+extern void hv_hyp_synic_enable_regs(unsigned int cpu);
extern int hv_synic_init(unsigned int cpu);
-extern void hv_synic_disable_regs(unsigned int cpu);
+extern void hv_hyp_synic_disable_regs(unsigned int cpu);
extern int hv_synic_cleanup(unsigned int cpu);
/* Interface */
diff --git a/drivers/hv/vmbus_drv.c b/drivers/hv/vmbus_drv.c
index 5a5d7e696f31..aa0cde8b8a71 100644
--- a/drivers/hv/vmbus_drv.c
+++ b/drivers/hv/vmbus_drv.c
@@ -2812,7 +2812,7 @@ static void hv_crash_handler(struct pt_regs *regs)
*/
cpu = smp_processor_id();
hv_stimer_cleanup(cpu);
- hv_synic_disable_regs(cpu);
+ hv_hyp_synic_disable_regs(cpu);
};
static int hv_synic_suspend(void)
@@ -2837,14 +2837,14 @@ static int hv_synic_suspend(void)
* interrupts-disabled context.
*/
- hv_synic_disable_regs(0);
+ hv_hyp_synic_disable_regs(0);
return 0;
}
static void hv_synic_resume(void)
{
- hv_synic_enable_regs(0);
+ hv_hyp_synic_enable_regs(0);
/*
* Note: we don't need to call hv_stimer_init(0), because the timer
diff --git a/drivers/hv/hv.c b/drivers/hv/hv.c
index 7c5f35806e77..efe161d95b25 100644
--- a/drivers/hv/hv.c
+++ b/drivers/hv/hv.c
@@ -271,9 +271,10 @@ void hv_synic_free(void)
}
/*
* hv_synic_enable_regs - Initialize the Synthetic Interrupt Controller.
*/
-void hv_synic_enable_regs(unsigned int cpu)
+void hv_hyp_synic_enable_regs(unsigned int cpu)
{
struct hv_per_cpu_context *hv_cpu =
per_cpu_ptr(hv_context.cpu_context, cpu);
@@ -339,14 +340,14 @@ void hv_synic_enable_regs(unsigned int cpu)
int hv_synic_init(unsigned int cpu)
{
- hv_synic_enable_regs(cpu);
+ hv_hyp_synic_enable_regs(cpu);
hv_stimer_legacy_init(cpu, VMBUS_MESSAGE_SINT);
return 0;
}
-void hv_synic_disable_regs(unsigned int cpu)
+void hv_hyp_synic_disable_regs(unsigned int cpu)
{
struct hv_per_cpu_context *hv_cpu =
per_cpu_ptr(hv_context.cpu_context, cpu);
@@ -533,7 +534,7 @@ int hv_synic_cleanup(unsigned int cpu)
always_cleanup:
hv_stimer_legacy_cleanup(cpu);
- hv_synic_disable_regs(cpu);
+ hv_hyp_synic_disable_regs(cpu);
return ret;
}
@@ -271,9 +271,10 @@ void hv_synic_free(void)
}
/*
- * hv_synic_enable_regs - Initialize the Synthetic Interrupt Controller.
+ * hv_hyp_synic_enable_regs - Initialize the Synthetic Interrupt Controller
+ * with the hypervisor.
*/
--
2.43.0
next prev parent reply other threads:[~2025-08-28 1:06 UTC|newest]
Thread overview: 25+ messages / expand[flat|nested] mbox.gz Atom feed top
2025-08-28 1:05 [PATCH hyperv-next v5 00/16] Confidential VMBus Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 01/16] Documentation: hyperv: " Roman Kisel
2025-09-09 3:09 ` Michael Kelley
2025-08-28 1:05 ` [PATCH hyperv-next v5 02/16] drivers: hv: VMBus protocol version 6.0 Roman Kisel
2025-09-09 3:10 ` Michael Kelley
2025-08-28 1:05 ` [PATCH hyperv-next v5 03/16] arch: hyperv: Get/set SynIC synth.registers via paravisor Roman Kisel
2025-09-09 3:10 ` Michael Kelley
2025-08-28 1:05 ` [PATCH hyperv-next v5 04/16] arch/x86: mshyperv: Trap on access for some synthetic MSRs Roman Kisel
2025-09-09 3:11 ` Michael Kelley
2025-09-30 21:59 ` Wei Liu
2025-08-28 1:05 ` [PATCH hyperv-next v5 05/16] Drivers: hv: Rename fields for SynIC message and event pages Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 06/16] Drivers: hv: Allocate the paravisor SynIC pages when required Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 07/16] Drivers: hv: Post messages through the confidential VMBus if available Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 08/16] Drivers: hv: remove stale comment Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 09/16] Drivers: hv: Check message and event pages for non-NULL before iounmap() Roman Kisel
2025-08-28 1:05 ` Roman Kisel [this message]
2025-08-28 1:05 ` [PATCH hyperv-next v5 11/16] Drivers: hv: Functions for setting up and tearing down the paravisor SynIC Roman Kisel
2025-09-09 3:12 ` Michael Kelley
2025-08-28 1:05 ` [PATCH hyperv-next v5 12/16] Drivers: hv: Allocate encrypted buffers when requested Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 13/16] Drivers: hv: Free msginfo when the buffer fails to decrypt Roman Kisel
2025-09-09 3:14 ` Michael Kelley
2025-08-28 1:05 ` [PATCH hyperv-next v5 14/16] Drivers: hv: Support confidential VMBus channels Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 15/16] Drivers: hv: Set the default VMBus version to 6.0 Roman Kisel
2025-08-28 1:05 ` [PATCH hyperv-next v5 16/16] Drivers: hv: Support establishing the confidential VMBus connection Roman Kisel
2025-09-09 3:09 ` [PATCH hyperv-next v5 00/16] Confidential VMBus Michael Kelley
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20250828010557.123869-11-romank@linux.microsoft.com \
--to=romank@linux.microsoft.com \
--cc=Tianyu.Lan@microsoft.com \
--cc=arnd@arndb.de \
--cc=benhill@microsoft.com \
--cc=bp@alien8.de \
--cc=bperkins@microsoft.com \
--cc=corbet@lwn.net \
--cc=dave.hansen@linux.intel.com \
--cc=decui@microsoft.com \
--cc=haiyangz@microsoft.com \
--cc=hpa@zytor.com \
--cc=kys@microsoft.com \
--cc=linux-arch@vger.kernel.org \
--cc=linux-doc@vger.kernel.org \
--cc=linux-hyperv@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mikelley@microsoft.com \
--cc=mingo@redhat.com \
--cc=sunilmut@microsoft.com \
--cc=tglx@linutronix.de \
--cc=wei.liu@kernel.org \
--cc=x86@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.